import type { CallToolMeta, PromptConfig, ResourceConfig, ResourceTemplateConfig, ServerOptions, ToolConfig, Version } from "../types";
import { Server } from "@modelcontextprotocol/sdk/server/index.js";
import ResourceManager from "./ResourceManager";
import { type Root, type LoggingLevel } from "@modelcontextprotocol/sdk/types.js";
import ToolManager from "./ToolManager";
import PromptManager from "./PromptManager";
import { Context } from "./Context";
import RootsManager from "./RootsManager";
declare class BaseMCP {
    name: string;
    opts: ServerOptions;
    resourceManager: ResourceManager;
    toolManager: ToolManager;
    promptManager: PromptManager;
    rootsManager: RootsManager;
    server: Server | null;
    constructor(name: string, opts: ServerOptions);
    listCapabilities(): {
        resources: import("../types").ResourceDefinition[];
        resourceTemplates: import("../types").ResourceTemplateDefinition[];
        tools: import("../types").SerializableTool[];
        prompts: import("../types").PromptDefinition[];
        roots: import("zod").objectOutputType<{
            uri: import("zod").ZodString;
            name: import("zod").ZodOptional<import("zod").ZodString>;
        }, import("zod").ZodTypeAny, "passthrough">[];
    };
    registerCapabilities(): {
        capabilities: import("zod").objectOutputType<{
            experimental: import("zod").ZodOptional<import("zod").ZodObject<{}, "passthrough", import("zod").ZodTypeAny, import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough">, import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough">>>;
            logging: import("zod").ZodOptional<import("zod").ZodObject<{}, "passthrough", import("zod").ZodTypeAny, import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough">, import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough">>>;
            prompts: import("zod").ZodOptional<import("zod").ZodObject<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, "passthrough", import("zod").ZodTypeAny, import("zod").objectOutputType<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">, import("zod").objectInputType<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">>>;
            resources: import("zod").ZodOptional<import("zod").ZodObject<{
                subscribe: import("zod").ZodOptional<import("zod").ZodBoolean>;
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, "passthrough", import("zod").ZodTypeAny, import("zod").objectOutputType<{
                subscribe: import("zod").ZodOptional<import("zod").ZodBoolean>;
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">, import("zod").objectInputType<{
                subscribe: import("zod").ZodOptional<import("zod").ZodBoolean>;
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">>>;
            tools: import("zod").ZodOptional<import("zod").ZodObject<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, "passthrough", import("zod").ZodTypeAny, import("zod").objectOutputType<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">, import("zod").objectInputType<{
                listChanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod").ZodTypeAny, "passthrough">>>;
        }, import("zod").ZodTypeAny, "passthrough">;
    };
    serve(): Promise<void>;
    tool(config: ToolConfig): void;
    resource(config: ResourceConfig): void;
    template(config: ResourceTemplateConfig): void;
    prompt(config: PromptConfig): void;
    root(config: Root): void;
    createContext(meta: CallToolMeta): Promise<Context>;
    private registerCoreHandlers;
    sendLog({ level, message }: {
        level: LoggingLevel;
        message: string;
    }): void;
    static create(name: string, opts: ServerOptions): BaseMCP;
}
export default class EasyMCP extends BaseMCP {
    constructor({ version, description, }: {
        version: Version;
        description?: string;
    });
}
export {};
